@@ -18,7 +18,7 @@
 ///////////////////////////////////////////////////////////////////
 
 static int num_versions=2; // number of different weed api versions supported
-static int api_versions[]={131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
+static int api_versions[]= {131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
 
 static int package_version=1; // version of this package
 
@@ -42,7 +42,7 @@ typedef struct {
 
 //////////////////////////////////////////////
 
-int alien_over_init (weed_plant_t *inst) {
+int alien_over_init(weed_plant_t *inst) {
   int error;
   weed_plant_t *in_channel=weed_get_plantptr_value(inst,"in_channels",&error);
 
@@ -61,7 +61,7 @@ int alien_over_init (weed_plant_t *inst) {
 }
 
 
-int alien_over_deinit (weed_plant_t *inst) {
+int alien_over_deinit(weed_plant_t *inst) {
   int error;
   static_data *sdata=weed_get_voidptr_value(inst,"plugin_internal",&error);
   if (sdata!=NULL) {
@@ -74,9 +74,10 @@ int alien_over_deinit (weed_plant_t *inst) {
 }
 
 
-int alien_over_process (weed_plant_t *inst, weed_timecode_t timestamp) {
+int alien_over_process(weed_plant_t *inst, weed_timecode_t timestamp) {
   int error;
-  weed_plant_t *in_channel=weed_get_plantptr_value(inst,"in_channels",&error),*out_channel=weed_get_plantptr_value(inst,"out_channels",&error);
+  weed_plant_t *in_channel=weed_get_plantptr_value(inst,"in_channels",&error),*out_channel=weed_get_plantptr_value(inst,"out_channels",
+                           &error);
   unsigned char *src=weed_get_voidptr_value(in_channel,"pixel_data",&error);
   unsigned char *dst=weed_get_voidptr_value(out_channel,"pixel_data",&error);
   int width=weed_get_int_value(in_channel,"width",&error)*3;
@@ -105,20 +106,18 @@ int alien_over_process (weed_plant_t *inst, weed_timecode_t timestamp) {
     old_pixel_data+=width*offset;
   }
 
-  for (;src<end;src+=irowstride) {
-    for (j=0;j<width;j++) {
+  for (; src<end; src+=irowstride) {
+    for (j=0; j<width; j++) {
       if (sdata->inited) {
-	if (!inplace) {
-	  dst[j]=((char)(old_pixel_data[j])+(char)(src[j]))>>1;
-	  old_pixel_data[j]=src[j];
-	}
-	else {
-	  val=((char)(old_pixel_data[j])+(char)(src[j]))>>1;
-	  old_pixel_data[j]=src[j];
-	  dst[j]=val;
-	}
-      }
-      else old_pixel_data[j]=dst[j]=src[j];
+        if (!inplace) {
+          dst[j]=((char)(old_pixel_data[j])+(char)(src[j]))>>1;
+          old_pixel_data[j]=src[j];
+        } else {
+          val=((char)(old_pixel_data[j])+(char)(src[j]))>>1;
+          old_pixel_data[j]=src[j];
+          dst[j]=val;
+        }
+      } else old_pixel_data[j]=dst[j]=src[j];
     }
     dst+=orowstride;
     old_pixel_data+=width;
@@ -129,18 +128,19 @@ int alien_over_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 }
 
 
-weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
+weed_plant_t *weed_setup(weed_bootstrap_f weed_boot) {
   weed_plant_t *plugin_info=weed_plugin_info_init(weed_boot,num_versions,api_versions);
 
   if (plugin_info!=NULL) {
-    int palette_list[]={WEED_PALETTE_BGR24,WEED_PALETTE_RGB24,WEED_PALETTE_END};
-    weed_plant_t *in_chantmpls[]={weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,palette_list),NULL};
-    weed_plant_t *out_chantmpls[]={weed_channel_template_init("out channel 0",WEED_CHANNEL_CAN_DO_INPLACE,palette_list),NULL};
-    
-    weed_plant_t *filter_class=weed_filter_class_init("alien overlay","salsaman",1,WEED_FILTER_HINT_MAY_THREAD,&alien_over_init,&alien_over_process,&alien_over_deinit,in_chantmpls,out_chantmpls,NULL,NULL);
-    
-    weed_plugin_info_add_filter_class (plugin_info,filter_class);
-    
+    int palette_list[]= {WEED_PALETTE_BGR24,WEED_PALETTE_RGB24,WEED_PALETTE_END};
+    weed_plant_t *in_chantmpls[]= {weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,palette_list),NULL};
+    weed_plant_t *out_chantmpls[]= {weed_channel_template_init("out channel 0",WEED_CHANNEL_CAN_DO_INPLACE,palette_list),NULL};
+
+    weed_plant_t *filter_class=weed_filter_class_init("alien overlay","salsaman",1,WEED_FILTER_HINT_MAY_THREAD,&alien_over_init,
+                               &alien_over_process,&alien_over_deinit,in_chantmpls,out_chantmpls,NULL,NULL);
+
+    weed_plugin_info_add_filter_class(plugin_info,filter_class);
+
     weed_set_int_value(plugin_info,"version",package_version);
   }
 
