@@ -17,7 +17,7 @@
 ///////////////////////////////////////////////////////////////////
 
 static int num_versions=1; // number of different weed api versions supported
-static int api_versions[]={131}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
+static int api_versions[]= {131}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
 
 static int package_version=1; // version of this package
 
@@ -53,15 +53,16 @@ typedef struct {
 
 static size_t sizf=sizeof(float);
 
-float freq[NSLICES]={25.,50.,75.,100.,150.,200.,250.,300.,
-		     400.,500.,600.,
-		     700.,800.,900.,1000.,1100.,1200.,1300.,1400.,
-		     1600.,1800.,2000.,2200.,2400.,2600.,2800.,3000.,
-		     3200.,3600.,4000.,4400.,4800,5200.,5600.,6000.,
-		     6400.,6800.,
-		     7400.,8000.,8600.,9200.,9800.,10400.,11000.,11600.,
-		     12400.,13200,14000.,14800.,15600.,16400.,17600.,18800.,
-		     20000.};
+float freq[NSLICES]= {25.,50.,75.,100.,150.,200.,250.,300.,
+                      400.,500.,600.,
+                      700.,800.,900.,1000.,1100.,1200.,1300.,1400.,
+                      1600.,1800.,2000.,2200.,2400.,2600.,2800.,3000.,
+                      3200.,3600.,4000.,4400.,4800,5200.,5600.,6000.,
+                      6400.,6800.,
+                      7400.,8000.,8600.,9200.,9800.,10400.,11000.,11600.,
+                      12400.,13200,14000.,14800.,15600.,16400.,17600.,18800.,
+                      20000.
+                     };
 
 
 #define MAXPLANS 18
@@ -88,7 +89,7 @@ static int twopow(int i) {
   // return 2**(i+1)
   register int j,x=2;
 
-  for (j=0;j<i;j++) x*=2;
+  for (j=0; j<i; j++) x*=2;
 
   return x;
 }
@@ -97,20 +98,20 @@ static int twopow(int i) {
 static int create_plans(void) {
   register int i,nsamps;
 
-  for (i=0;i<MAXPLANS;i++) {
+  for (i=0; i<MAXPLANS; i++) {
     // create fftw plan
     nsamps=twopow(i);
 
-    ins[i] = (float*) fftwf_malloc(nsamps*sizeof(float));
+    ins[i] = (float *) fftwf_malloc(nsamps*sizeof(float));
     if (ins[i]==NULL) {
       return WEED_ERROR_MEMORY_ALLOCATION;
     }
-    
-    outs[i] = (fftwf_complex*) fftwf_malloc(nsamps*sizeof(fftwf_complex));
+
+    outs[i] = (fftwf_complex *) fftwf_malloc(nsamps*sizeof(fftwf_complex));
     if (outs[i]==NULL) {
       return WEED_ERROR_MEMORY_ALLOCATION;
     }
-    
+
     plans[i] = fftwf_plan_dft_r2c_1d(nsamps, ins[i], outs[i], i<13?FFTW_MEASURE:FFTW_ESTIMATE);
   }
   return WEED_NO_ERROR;
@@ -129,14 +130,14 @@ int beat_init(weed_plant_t *inst) {
     return WEED_ERROR_MEMORY_ALLOCATION;
   }
 
-  for (i=0;i<NSLICES;i++) {
+  for (i=0; i<NSLICES; i++) {
     sdata->av[i]=0.;
-     for (j=0;j<BUFMAX;j++) {
+    for (j=0; j<BUFMAX; j++) {
       sdata->buf[i][j]=0.;
     }
   }
 
-  for (j=0;j<BUFMAX;j++) {
+  for (j=0; j<BUFMAX; j++) {
     sdata->bufsize[j]=0;
   }
 
@@ -165,7 +166,7 @@ int beat_deinit(weed_plant_t *inst) {
 
 
 
-int beat_process (weed_plant_t *inst, weed_timecode_t timestamp) {
+int beat_process(weed_plant_t *inst, weed_timecode_t timestamp) {
   int error;
   int chans,nsamps,onsamps,base,inter,rate,k;
 
@@ -207,7 +208,7 @@ int beat_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 
 
   rate=weed_get_int_value(in_channel,"audio_rate",&error);
-    
+
   chans=weed_get_int_value(in_channel,"audio_channels",&error);
   inter=weed_get_boolean_value(in_channel,"audio_interleaf",&error);
 
@@ -216,18 +217,17 @@ int beat_process (weed_plant_t *inst, weed_timecode_t timestamp) {
     sdata->totsamps-=sdata->bufsize[0];
     // shift all values up
 
-    for (i=0;i<NSLICES;i++) {
+    for (i=0; i<NSLICES; i++) {
       sdata->av[i]=0.;
 
-      for (j=0;j<sdata->bufidx;j++) {
-	sdata->buf[i][j]=sdata->buf[i][j+1];
-	if (sdata->buf[i][j]!=-1.) sdata->av[i]+=(double)sdata->buf[i][j];
+      for (j=0; j<sdata->bufidx; j++) {
+        sdata->buf[i][j]=sdata->buf[i][j+1];
+        if (sdata->buf[i][j]!=-1.) sdata->av[i]+=(double)sdata->buf[i][j];
       }
     }
 
     has_data=WEED_TRUE;
-  }
-  else {
+  } else {
     sdata->bufidx++;
     if (sdata->bufidx==BUFMAX) {
       //fprintf(stderr,"OVERFLOW\n");
@@ -238,54 +238,51 @@ int beat_process (weed_plant_t *inst, weed_timecode_t timestamp) {
   sdata->totsamps+=onsamps;
   sdata->bufsize[sdata->bufidx]=onsamps;
 
-  for (s=0;s<NSLICES;s++) {
+  for (s=0; s<NSLICES; s++) {
     sdata->buf[s][sdata->bufidx]=0.;
   }
 
   base=rndlog2(onsamps);
   nsamps=twopow(base);
 
-  for (i=0;i<chans;i++) {
+  for (i=0; i<chans; i++) {
     // do transform for each channel
-      
+
     // copy in data to sdata->in
     if (inter==WEED_FALSE) {
       // non-interleaved
       if (hamming==WEED_TRUE) {
-	for (j=0;j<nsamps;j++) {
-	  ins[base][j]=src[j]*(0.54f - 0.46f * cosf(TWO_PI*(float)j/(float)(nsamps-1.)));
-	}
-      }
-      else {
-	weed_memcpy(ins[base],src,nsamps*sizf);
+        for (j=0; j<nsamps; j++) {
+          ins[base][j]=src[j]*(0.54f - 0.46f * cosf(TWO_PI*(float)j/(float)(nsamps-1.)));
+        }
+      } else {
+        weed_memcpy(ins[base],src,nsamps*sizf);
       }
       src+=onsamps;
-    }
-    else {
+    } else {
       // interleaved
-      for (j=0;j<nsamps;j++) {
-	if (hamming==WEED_TRUE) {
-	  ins[base][j]=src[j*chans]*(0.54f - 0.46f * cosf(TWO_PI*(float)j/(float)(nsamps-1.)));
-	}
-	else {
-	  ins[base][j]=src[j*chans];
-	}
+      for (j=0; j<nsamps; j++) {
+        if (hamming==WEED_TRUE) {
+          ins[base][j]=src[j*chans]*(0.54f - 0.46f * cosf(TWO_PI*(float)j/(float)(nsamps-1.)));
+        } else {
+          ins[base][j]=src[j*chans];
+        }
       }
       src++;
     }
 
 
 
-      
+
     //fprintf(stderr,"executing plan of size %d\n",sdata->size);
     fftwf_execute(plans[base]);
 
     okmin=kmin=0;
 
-    for (s=0;s<NSLICES;s++) {
+    for (s=0; s<NSLICES; s++) {
       // which element do we want for output ?
       // out array goes from 0 to (nsamps/2 + 1) [div b y 2 rounded down]
-	
+
       // nyquist freq is rate / 2
       // so the freq. of the kth element is: f  =  k/nsamps * rate
       // therefore k = f/rate * nsamps
@@ -294,41 +291,39 @@ int beat_process (weed_plant_t *inst, weed_timecode_t timestamp) {
       kmax = freq[s]/(double)rate*(double)nsamps;
 
       if (kmax>=(nsamps>>1)) {
-	// frequency invalid - too high for this sample packet
-	tot=-1.;
-	sdata->buf[s][sdata->bufidx]=tot;
-      }
-      else {
+        // frequency invalid - too high for this sample packet
+        tot=-1.;
+        sdata->buf[s][sdata->bufidx]=tot;
+      } else {
 
-	// use an overlap
-	rkmin=kmin-((kmin-okmin)>>1);
-	if (s<NSLICES-1) {
-	  rkmax=kmax+(freq[s+1]-freq[s])/2./(double)rate*(double)nsamps;
-	  if (rkmax>=(nsamps>>1)) {
-	    rkmax=kmax;
-	  }
-	}
-	else rkmax=kmax;
+        // use an overlap
+        rkmin=kmin-((kmin-okmin)>>1);
+        if (s<NSLICES-1) {
+          rkmax=kmax+(freq[s+1]-freq[s])/2./(double)rate*(double)nsamps;
+          if (rkmax>=(nsamps>>1)) {
+            rkmax=kmax;
+          }
+        } else rkmax=kmax;
 
-	totx=0.;
+        totx=0.;
 
-	for (k=rkmin;k<=rkmax;k++) {
-	  // sum values over range
-	  // average over range
-	  totx+=sqrtf(outs[base][k][0]*outs[base][k][0]+outs[base][k][1]*outs[base][k][1]);
-	}
+        for (k=rkmin; k<=rkmax; k++) {
+          // sum values over range
+          // average over range
+          totx+=sqrtf(outs[base][k][0]*outs[base][k][0]+outs[base][k][1]*outs[base][k][1]);
+        }
 
-	// average over bandwidth
-	totx/=((float)rkmax-(float)rkmin+1.);
+        // average over bandwidth
+        totx/=((float)rkmax-(float)rkmin+1.);
 
-	// boost lower freq
-	totx/=((float)rkmax-(float)rkmin+1.);
+        // boost lower freq
+        totx/=((float)rkmax-(float)rkmin+1.);
 
-	// store this value in the buffer
-	sdata->buf[s][sdata->bufidx]+=totx/(float)chans;
+        // store this value in the buffer
+        sdata->buf[s][sdata->bufidx]+=totx/(float)chans;
 
-	okmin=kmin;
-	kmin=kmax;
+        okmin=kmin;
+        kmin=kmax;
       }
     } // done for all slices
   } // done for all channels
@@ -350,21 +345,21 @@ int beat_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 
   var=0.;
 
-  for (i=0;i<NSLICES;i++) {
+  for (i=0; i<NSLICES; i++) {
     // for the variance:
     //av=sdata->av[i]/(double)sdata->bufidx;
 
     if (sdata->bufidx>ONSET_WINDOW) {
       float val1,val2,varx;
-      for (j=sdata->bufidx-ONSET_WINDOW;j<=sdata->bufidx;j++) {
-	if (
-	    (val1=sdata->buf[i][j])!=-1.&&
-	    (val2=sdata->buf[i][j-1])!=-1.
-	    ) {
-	  varx=(val1-val2);
-	  if (varx<0.) varx=0.;
-	  var+=(double)varx/(double)ONSET_WINDOW;
-	}
+      for (j=sdata->bufidx-ONSET_WINDOW; j<=sdata->bufidx; j++) {
+        if (
+          (val1=sdata->buf[i][j])!=-1.&&
+          (val2=sdata->buf[i][j-1])!=-1.
+        ) {
+          varx=(val1-val2);
+          if (varx<0.) varx=0.;
+          var+=(double)varx/(double)ONSET_WINDOW;
+        }
       }
     }
   }
@@ -375,7 +370,7 @@ int beat_process (weed_plant_t *inst, weed_timecode_t timestamp) {
   var/=(double)NSLICES;
 
 
-  for (i=0;i<NSLICES;i++) {
+  for (i=0; i<NSLICES; i++) {
     av=sdata->av[i]/(double)sdata->bufidx;
     if (var>=varlim && sdata->buf[i][sdata->bufidx] >= (avlim*av)) {
       // got a beat !
@@ -388,36 +383,37 @@ int beat_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 
   //fprintf(stderr,"\n\n");
 
- done:
+done:
   weed_set_boolean_value(out_params[0],"value",beat_pulse);
   weed_set_int64_value(out_params[0],"timecode",timestamp);
   weed_set_boolean_value(out_params[1],"value",beat_hold);
   weed_set_int64_value(out_params[1],"timecode",timestamp);
 
   weed_free(out_params);
-  
+
   return WEED_NO_ERROR;
 }
 
 
 
 
-weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
+weed_plant_t *weed_setup(weed_bootstrap_f weed_boot) {
   weed_plant_t *plugin_info;
   if (create_plans()!=WEED_NO_ERROR) return NULL;
   plugin_info=weed_plugin_info_init(weed_boot,num_versions,api_versions);
   if (plugin_info!=NULL) {
-    weed_plant_t *in_chantmpls[]={weed_audio_channel_template_init("in channel 0",0),NULL};
-    weed_plant_t *in_params[]={weed_switch_init("reset","_Reset hold",WEED_FALSE),weed_float_init("avlim","_Average threshold",3.,0.,40.),
-			       weed_float_init("varlim","_Variance threshold",0.5,0.,10.),weed_switch_init("hamming","Use _Hamming",WEED_TRUE),NULL};
-    weed_plant_t *out_params[]={weed_out_param_switch_init("beat pulse",WEED_FALSE),weed_out_param_switch_init("beat hold",WEED_FALSE),NULL};
+    weed_plant_t *in_chantmpls[]= {weed_audio_channel_template_init("in channel 0",0),NULL};
+    weed_plant_t *in_params[]= {weed_switch_init("reset","_Reset hold",WEED_FALSE),weed_float_init("avlim","_Average threshold",3.,0.,40.),
+                                weed_float_init("varlim","_Variance threshold",0.5,0.,10.),weed_switch_init("hamming","Use _Hamming",WEED_TRUE),NULL
+                               };
+    weed_plant_t *out_params[]= {weed_out_param_switch_init("beat pulse",WEED_FALSE),weed_out_param_switch_init("beat hold",WEED_FALSE),NULL};
     weed_plant_t *filter_class=weed_filter_class_init("beat detector","salsaman",1,0,&beat_init,&beat_process,
-						      &beat_deinit,in_chantmpls,NULL,in_params,out_params);
+                               &beat_deinit,in_chantmpls,NULL,in_params,out_params);
 
     weed_plant_t *gui=weed_parameter_template_get_gui(in_params[0]);
     weed_set_boolean_value(gui,"hidden",WEED_TRUE);
 
-    weed_plugin_info_add_filter_class (plugin_info,filter_class);
+    weed_plugin_info_add_filter_class(plugin_info,filter_class);
 
     weed_set_int_value(plugin_info,"version",package_version);
   }
@@ -427,7 +423,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 
 void weed_desetup(void) {
   register int i;
-  for (i=0;i<MAXPLANS;i++) {
+  for (i=0; i<MAXPLANS; i++) {
     fftwf_destroy_plan(plans[i]);
     fftwf_free(ins[i]);
     fftwf_free(outs[i]);
