@@ -18,7 +18,7 @@
 ///////////////////////////////////////////////////////////////////
 
 static int num_versions=2; // number of different weed api versions supported
-static int api_versions[]={131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
+static int api_versions[]= {131,100}; // array of weed api versions supported in plugin, in order of preference (most preferred first)
 
 static int package_version=1; // version of this package
 
@@ -54,8 +54,8 @@ int edge_init(weed_plant_t *inst) {
   weed_plant_t *in_channel;
   int error,height,width;
 
-  static_data *sdata=(static_data *)weed_malloc (sizeof(static_data));
-  if(sdata == NULL ) return WEED_ERROR_MEMORY_ALLOCATION;
+  static_data *sdata=(static_data *)weed_malloc(sizeof(static_data));
+  if (sdata == NULL) return WEED_ERROR_MEMORY_ALLOCATION;
 
   in_channel=weed_get_plantptr_value(inst,"in_channels",&error);
   height=weed_get_int_value(in_channel,"height",&error);
@@ -74,7 +74,7 @@ int edge_init(weed_plant_t *inst) {
 }
 
 
-int edge_deinit (weed_plant_t *inst) {
+int edge_deinit(weed_plant_t *inst) {
   static_data *sdata;
   int error;
 
@@ -95,9 +95,10 @@ static inline RGB32 copywalpha(RGB32 *dest, RGB32 *src, size_t offs, RGB32 val)
 }
 
 
-int edge_process (weed_plant_t *inst, weed_timecode_t timestamp) {
+int edge_process(weed_plant_t *inst, weed_timecode_t timestamp) {
   int error;
-  weed_plant_t *in_channel=weed_get_plantptr_value(inst,"in_channels",&error),*out_channel=weed_get_plantptr_value(inst,"out_channels",&error);
+  weed_plant_t *in_channel=weed_get_plantptr_value(inst,"in_channels",&error),*out_channel=weed_get_plantptr_value(inst,"out_channels",
+                           &error);
   RGB32 *src=weed_get_voidptr_value(in_channel,"pixel_data",&error);
   RGB32 *dest=weed_get_voidptr_value(out_channel,"pixel_data",&error);
   int video_width=weed_get_int_value(in_channel,"width",&error);
@@ -116,11 +117,11 @@ int edge_process (weed_plant_t *inst, weed_timecode_t timestamp) {
   src += video_width*4+4;
   dest += video_width*4+4;
 
-  for(y=1; y<map_height-1; y++) {
-    for(x=1; x<map_width-1; x++) {
+  for (y=1; y<map_height-1; y++) {
+    for (x=1; x<map_width-1; x++) {
       p = *src;
       q = *(src - 4);
-      
+
       /* difference between the current pixel and right neighbor. */
       r = ((int)(p & 0xff0000) - (int)(q & 0xff0000))>>16;
       g = ((int)(p & 0x00ff00) - (int)(q & 0x00ff00))>>8;
@@ -131,11 +132,11 @@ int edge_process (weed_plant_t *inst, weed_timecode_t timestamp) {
       r >>=5; /* To lack the lower bit for saturated addition,  */
       g >>=5; /* devide the value with 32, instead of 16. It is */
       b >>=4; /* same as `v2 &= 0xfefeff' */
-      if(r>127) r = 127;
-      if(g>127) g = 127;
-      if(b>255) b = 255;
+      if (r>127) r = 127;
+      if (g>127) g = 127;
+      if (b>255) b = 255;
       v2 = (r<<17)|(g<<9)|b;
-      
+
       /* difference between the current pixel and upper neighbor. */
       q = *(src - video_width*4);
       r = ((int)(p & 0xff0000) - (int)(q & 0xff0000))>>16;
@@ -147,13 +148,15 @@ int edge_process (weed_plant_t *inst, weed_timecode_t timestamp) {
       r>>=5;
       g>>=5;
       b>>=4;
-      if(r>127) r = 127;
-      if(g>127) g = 127;
-      if(b>255) b = 255;
+      if (r>127) r = 127;
+      if (g>127) g = 127;
+      if (b>255) b = 255;
       v3 = (r<<17)|(g<<9)|b;
-      
-      map[y*map_width*2+x*2+1] = copywalpha(dest,src,2,copywalpha(dest,src,3,copywalpha(dest,src,video_width+2,copywalpha(dest,src,video_width+3,v3))));
-      map[y*map_width*2+x*2] = copywalpha(dest,src,video_width*2,copywalpha(dest,src,video_width*2+1,copywalpha(dest,src,video_width*3,copywalpha(dest,src,video_width*3+1,v2))));
+
+      map[y*map_width*2+x*2+1] = copywalpha(dest,src,2,copywalpha(dest,src,3,copywalpha(dest,src,video_width+2,copywalpha(dest,src,video_width+3,
+                                            v3))));
+      map[y*map_width*2+x*2] = copywalpha(dest,src,video_width*2,copywalpha(dest,src,video_width*2+1,copywalpha(dest,src,video_width*3,
+                                          copywalpha(dest,src,video_width*3+1,v2))));
 
       v0 = map[(y-1)*map_width*2+x*2];
       v1 = map[y*map_width*2+(x-1)*2+1];
@@ -166,7 +169,7 @@ int edge_process (weed_plant_t *inst, weed_timecode_t timestamp) {
       copywalpha(dest,src,video_width,r | (g - (g>>8)));
       g = (r=v2+v3) & 0x01010100;
       copywalpha(dest,src,video_width+1,r | (g - (g>>8)));
-      
+
       src += 4;
       dest += 4;
     }
@@ -177,16 +180,17 @@ int edge_process (weed_plant_t *inst, weed_timecode_t timestamp) {
 }
 
 
-weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
+weed_plant_t *weed_setup(weed_bootstrap_f weed_boot) {
   weed_plant_t *plugin_info=weed_plugin_info_init(weed_boot,num_versions,api_versions);
   if (plugin_info!=NULL) {
-    int palette_list[]={WEED_PALETTE_BGRA32,WEED_PALETTE_END};
+    int palette_list[]= {WEED_PALETTE_BGRA32,WEED_PALETTE_END};
 
-    weed_plant_t *in_chantmpls[]={weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,palette_list),NULL};
-    weed_plant_t *out_chantmpls[]={weed_channel_template_init("out channel 0",0,palette_list),NULL};
-    weed_plant_t *filter_class=weed_filter_class_init("edge detect","effectTV",1,0,&edge_init,&edge_process,&edge_deinit,in_chantmpls,out_chantmpls,NULL,NULL);
+    weed_plant_t *in_chantmpls[]= {weed_channel_template_init("in channel 0",WEED_CHANNEL_REINIT_ON_SIZE_CHANGE,palette_list),NULL};
+    weed_plant_t *out_chantmpls[]= {weed_channel_template_init("out channel 0",0,palette_list),NULL};
+    weed_plant_t *filter_class=weed_filter_class_init("edge detect","effectTV",1,0,&edge_init,&edge_process,&edge_deinit,in_chantmpls,
+                               out_chantmpls,NULL,NULL);
 
-    weed_plugin_info_add_filter_class (plugin_info,filter_class);
+    weed_plugin_info_add_filter_class(plugin_info,filter_class);
 
     weed_set_int_value(plugin_info,"version",package_version);
   }
