@@ -7,12 +7,12 @@
 #ifndef HAS_LIVES_INTERFACE_H
 #define HAS_LIVES_INTERFACE_H
 
-LiVESWidget* create_info_error_dialog (const gchar *text, boolean is_blocking, int mask, lives_info_t infotype);
-LiVESWidget* create_opensel_dialog (void);
-LiVESWidget* create_encoder_prep_dialog (const gchar *text1, const gchar *text2, boolean opt_resize);
+LiVESWidget *create_info_error_dialog(lives_dialog_t info_type, const char *text, LiVESWindow *transient, int mask, boolean is_blocking);
+LiVESWidget *create_opensel_dialog(void);
+LiVESWidget *create_encoder_prep_dialog(const char *text1, const char *text2, boolean opt_resize);
 
-void widget_add_preview(LiVESWidget *widget, LiVESBox *for_preview, LiVESBox *for_button, 
-			LiVESBox *for_deinterlace, int preview_type);  ///< for fileselector preview
+void widget_add_preview(LiVESWidget *widget, LiVESBox *for_preview, LiVESBox *for_button,
+                        LiVESBox *for_deinterlace, int preview_type);  ///< for fileselector preview
 
 boolean do_audio_choice_dialog(short startup_phase);
 
@@ -34,7 +34,7 @@ typedef struct {
   LiVESWidget *textview_rrate;
 } lives_clipinfo_t;
 
-lives_clipinfo_t * create_clip_info_window (int audio_channels, boolean is_mt);
+lives_clipinfo_t *create_clip_info_window(int audio_channels, boolean is_mt);
 
 
 typedef struct {
@@ -43,12 +43,12 @@ typedef struct {
   LiVESWidget *dir_entry;
   LiVESWidget *name_entry;
   LiVESWidget *warn_checkbutton;
-  GList *setlist;
+  LiVESList *setlist;
 } _entryw;
 
-_entryw* create_rename_dialog (int type);
-_entryw* create_location_dialog (int type);
-_entryw* create_cds_dialog (int type);
+_entryw *create_rename_dialog(int type);
+_entryw *create_location_dialog(int type);
+_entryw *create_cds_dialog(int type);
 
 typedef struct __insertw {
   LiVESWidget *insert_dialog;
@@ -58,7 +58,7 @@ typedef struct __insertw {
   LiVESWidget *fit_checkbutton;
 } _insertw;
 
-_insertw* create_insert_dialog (void);
+_insertw *create_insert_dialog(void);
 
 
 typedef struct __commentsw {
@@ -70,7 +70,7 @@ typedef struct __commentsw {
   LiVESWidget *subt_entry;
 } _commentsw;
 
-_commentsw* create_comments_dialog (lives_clip_t *sfile, gchar *filename);
+_commentsw *create_comments_dialog(lives_clip_t *sfile, char *filename);
 
 
 typedef struct {
@@ -80,7 +80,7 @@ typedef struct {
   LiVESWidget *textview;
 } text_window;
 
-text_window* create_text_window (const gchar *title_part, const gchar *text, LiVESTextBuffer *);
+text_window *create_text_window(const char *title_part, const char *text, LiVESTextBuffer *);
 
 
 typedef struct {
@@ -105,9 +105,18 @@ typedef struct {
 } lives_tvcardw_t;
 
 
+#define LIVES_PREVIEW_TYPE_VIDEO_AUDIO 1
+#define LIVES_PREVIEW_TYPE_AUDIO_ONLY 2
+#define LIVES_PREVIEW_TYPE_RANGE 3
 
-aud_dialog_t *create_audfade_dialog (int type);
-LiVESWidget *create_combo_dialog (int type, gpointer user_data);
+#define LIVES_FILE_SELECTION_VIDEO_AUDIO 1
+#define LIVES_FILE_SELECTION_AUDIO_ONLY 2
+#define LIVES_FILE_SELECTION_VIDEO_AUDIO_MULTI 3
+#define LIVES_FILE_SELECTION_VIDEO_RANGE 4
+
+
+aud_dialog_t *create_audfade_dialog(int type);
+LiVESWidget *create_combo_dialog(int type, livespointer user_data);
 
 _commentsw *commentsw;
 _entryw *renamew;
@@ -119,5 +128,7 @@ text_window *textwindow;
 #define DEF_AUD_FADE_SECS 10. ///< default time to offer fade audio in/out for
 
 
+#define MIN_MSGBOX_WIDTH ((int)(mainw->scr_width>1024?(820.*widget_opts.scale):600))
+
 
 #endif
