@@ -24,15 +24,15 @@ typedef struct {
 
 boolean rec(s_cam *cam);
 void camplay(s_cam *cam);
-void camstop (s_cam *cam);
-void camrew (s_cam *cam);
-void camff (s_cam *cam);
-void campause (s_cam *cam);
-void cameject (s_cam *cam);
+void camstop(s_cam *cam);
+void camrew(s_cam *cam);
+void camff(s_cam *cam);
+void campause(s_cam *cam);
+void cameject(s_cam *cam);
 
 void close_raw1394(raw1394handle_t handle);
 
-gchar *find_free_camfile(int format);
+char *find_free_camfile(int format);
 
 
 struct _dvgrabw {
@@ -46,8 +46,8 @@ struct _dvgrabw {
   LiVESWidget *split;
   LiVESXCursor *cursor;
   boolean playing;
-  gchar *dirname;
-  gchar *filename;
+  char *dirname;
+  char *filename;
   s_cam *cam;
 };
 
