@@ -1,6 +1,6 @@
 // mainwindow.h
 // LiVES (lives-exe)
-// (c) G. Finch <salsaman@gmail.com> 2003 - 2013
+// (c) G. Finch <salsaman@gmail.com> 2003 - 2015
 // Released under the GPL 3 or later
 // see file ../COPYING for licensing details
 
@@ -19,6 +19,8 @@
 
 #ifdef HAVE_PULSE_AUDIO
 #include "pulse.h"
+#else
+#include "audio.h"
 #endif
 
 // hardware related prefs
@@ -79,6 +81,7 @@
 #define ENC_DETAILS_WIN_H ((int)(600.*widget_opts.scale)) ///< horizontal size in pixels of the encoder output window
 #define ENC_DETAILS_WIN_V ((int)(200.*widget_opts.scale)) ///< vertical size in pixels of the encoder output window
 
+#define MIN_MSG_WIDTH_CHARS ((int)(40.*widget_opts.scale)) ///< min width of text on warning/error labels
 #define MAX_MSG_WIDTH_CHARS ((int)(100.*widget_opts.scale)) ///< max width of text on warning/error labels
 
 /// size of the fx dialog windows scrollwindow
@@ -89,6 +92,10 @@
 
 #define DEF_BUTTON_WIDTH ((int)(80.*widget_opts.scale))
 
+#define DEF_DIALOG_WIDTH 640
+#define DEF_DIALOG_HEIGHT 480
+
+
 ////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 /// number of function keys
@@ -141,29 +148,14 @@ typedef enum {
 
 
 typedef enum {
+  LIVES_DIALOG_INFO,
+  LIVES_DIALOG_ERROR,
   LIVES_DIALOG_WARN,
+  LIVES_DIALOG_WARN_WITH_CANCEL,
   LIVES_DIALOG_YESNO,
   LIVES_DIALOG_ABORT_CANCEL_RETRY
 } lives_dialog_t;
 
-typedef enum {
-  LIVES_INFO_TYPE_INFO,
-  LIVES_INFO_TYPE_WARNING,
-  LIVES_INFO_TYPE_QUESTION,
-  LIVES_INFO_TYPE_ERROR
-} lives_info_t;
-
-
-/// return values from abort/cancel/retry dialog and yes/no dialog
-enum {
-  LIVES_NO=0,
-  LIVES_YES,
-  LIVES_CANCEL,
-  LIVES_RETRY,
-  LIVES_ABORT,
-  LIVES_RESET
-};
-
 
 /// various return conditions from rendering (multitrack or after recording)
 typedef enum {
@@ -273,30 +265,31 @@ typedef struct {
 
 /// mainw->
 typedef struct {
-  gchar msg[512];
+  char msg[512];
 
   // files
   int current_file;
   int first_free_file;
   lives_clip_t *files[MAX_FILES+1]; ///< +1 for the clipboard
-  gchar vid_load_dir[PATH_MAX];
-  gchar vid_save_dir[PATH_MAX];
-  gchar vid_dl_dir[PATH_MAX];
-  gchar audio_dir[PATH_MAX];
-  gchar image_dir[PATH_MAX];
-  gchar proj_load_dir[PATH_MAX];
-  gchar proj_save_dir[PATH_MAX];
+  char vid_load_dir[PATH_MAX];
+  char vid_save_dir[PATH_MAX];
+  char vid_dl_dir[PATH_MAX];
+  char audio_dir[PATH_MAX];
+  char image_dir[PATH_MAX];
+  char proj_load_dir[PATH_MAX];
+  char proj_save_dir[PATH_MAX];
+  char recent_file[PATH_MAX];
   int untitled_number;
   int cap_number;
   int clips_available;
 
   /// hash table of clips in menu order
-  GList *cliplist;
+  LiVESList *cliplist;
 
-  GSList *clips_group;
+  LiVESSList *clips_group;
 
   /// sets
-  gchar set_name[256];   // actually 128 is the limit now
+  char set_name[256];   // actually 128 is the limit now, filesystem encoding
 
   // playback
   boolean faded;
@@ -344,9 +337,9 @@ typedef struct {
   boolean stored_event_list_changed;
   boolean stored_event_list_auto_changed;
   boolean stored_layout_save_all_vals;
-  gchar stored_layout_name[PATH_MAX];
+  char stored_layout_name[PATH_MAX];
 
-  GList *stored_layout_undos;
+  LiVESList *stored_layout_undos;
   size_t sl_undo_buffer_used;
   unsigned char *sl_undo_mem;
   int sl_undo_offset;
@@ -393,7 +386,7 @@ typedef struct {
   int foreign_width;
   int foreign_height;
   int foreign_bpp;
-  gchar *foreign_visual;
+  char *foreign_visual;
 
   /// some VJ effects
   boolean nervous;
@@ -413,11 +406,11 @@ typedef struct {
 
   uint64_t rte; ///< current max for VJ mode == 64 effects on fg clip
 
-  uint32_t last_grabable_effect;
+  uint32_t last_grabbable_effect;
   int rte_keys; ///< which effect is bound to keyboard
   int num_tr_applied; ///< number of transitions active
   double blend_factor; ///< keyboard control parameter
-  
+
   int blend_file;
   int last_blend_file;
 
@@ -426,7 +419,7 @@ typedef struct {
   int ascrap_file; ///< scrap file for recording audio scraps
 
   /// which number file we are playing (or -1)
-  int playing_file;
+  volatile int playing_file;
 
   int pre_src_file; ///< video file we were playing before any ext input started
   int pre_src_audio_file; ///< audio file we were playing before any ext input started
@@ -471,12 +464,12 @@ typedef struct {
   /////////////////////////////////////////////////
 
   // end of static-ish info
-  gchar first_info_file[PATH_MAX];
+  char first_info_file[PATH_MAX];
   boolean leave_files;
   boolean was_set;
 
   /// extra parameters for opening special files
-  gchar *file_open_params;
+  char *file_open_params;
   boolean open_deint;
 
   int last_dprint_file;
@@ -505,9 +498,9 @@ typedef struct {
 
   boolean size_warn; ///< warn the user that incorrectly sized frames were found
 
-  /// set to TRUE during frame load/display operation. If TRUE we should not switch clips, 
+  /// set to TRUE during frame load/display operation. If TRUE we should not switch clips,
   /// close the current clip, or call load_frame_image()
-  boolean noswitch; 
+  boolean noswitch;
   int new_clip;
 
   int aud_file_to_kill; ///< # of audio file to kill on crash
@@ -517,7 +510,7 @@ typedef struct {
   /// TODO - make this a mutex and more finely grained : things we need to block are (clip switches, clip closure, effects on/off, etc)
   boolean osc_block;
 
-  boolean osc_auto; ///< bypass user choices automatically
+  int osc_auto; ///< bypass user choices automatically
 
   /// encode width, height and fps set externally
   int osc_enc_width;
@@ -541,7 +534,7 @@ typedef struct {
 
   /// internal fx
   boolean internal_messaging;
-  lives_render_error_t (*progress_fn) (boolean reset);
+  lives_render_error_t (*progress_fn)(boolean reset);
 
   volatile boolean threaded_dialog;
 
@@ -581,24 +574,24 @@ typedef struct {
   uint32_t kb_timer;
 
   //function pointers
-  gulong config_func;
-  gulong pb_fps_func;
-  gulong spin_start_func;
-  gulong spin_end_func;
-  gulong record_perf_func;
-  gulong vidbar_func;
-  gulong laudbar_func;
-  gulong raudbar_func;
-  gulong hrule_func;
-  gulong toy_func_none;
-  gulong toy_func_random_frames;
-  gulong toy_func_lives_tv;
-  gulong toy_func_autolives;
-  gulong hnd_id;
-  gulong loop_cont_func;
-  gulong mute_audio_func;
-  gulong fullscreen_cb_func;
-  gulong sepwin_cb_func;
+  ulong config_func;
+  ulong pb_fps_func;
+  ulong spin_start_func;
+  ulong spin_end_func;
+  ulong record_perf_func;
+  ulong vidbar_func;
+  ulong laudbar_func;
+  ulong raudbar_func;
+  ulong hrule_func;
+  ulong toy_func_none;
+  ulong toy_func_random_frames;
+  ulong toy_func_lives_tv;
+  ulong toy_func_autolives;
+  ulong hnd_id;
+  ulong loop_cont_func;
+  ulong mute_audio_func;
+  ulong fullscreen_cb_func;
+  ulong sepwin_cb_func;
 
   // for jack transport
   boolean jack_can_stop;
@@ -607,7 +600,7 @@ typedef struct {
   volatile boolean video_seek_ready;
 
   // selection pointers
-  gulong mouse_fn1;
+  ulong mouse_fn1;
   boolean mouse_blocked;
   boolean hrule_blocked;
 
@@ -795,7 +788,7 @@ typedef struct {
   weed_plant_t *filter_map; // the video filter map for rendering
   weed_plant_t *afilter_map; // the audio filter map for renering
   weed_plant_t *audio_event; // event for audio render tracking
-  void ***pchains; // parameter value chains for interpolation
+  void ** *pchains; // parameter value chains for interpolation
 
   // for the internal player
   LiVESWidget *play_image;
@@ -810,7 +803,7 @@ typedef struct {
   LiVESWidget *preview_spinbutton;
   LiVESWidget *preview_scale;
   int preview_frame;
-  gulong preview_spin_func;
+  ulong preview_spin_func;
   int prv_link;
 #define PRV_FREE 0
 #define PRV_START 1
@@ -932,7 +925,7 @@ typedef struct {
   boolean only_close; ///< only close clips - do not exit
   volatile boolean is_exiting; ///< set during shutdown (inverse of only_close then)
 
-  gulong pw_scroll_func;
+  ulong pw_scroll_func;
 
 #ifdef ENABLE_JACK
   jack_driver_t *jackd; ///< jack audio playback device
@@ -954,17 +947,17 @@ typedef struct {
 
   // layouts
   LiVESTextBuffer *layout_textbuffer; ///< stores layout errors
-  GList *affected_layouts_map; ///< map of layouts with errors
-  GList *current_layouts_map; ///< map of all layouts for set
+  LiVESList *affected_layouts_map; ///< map of layouts with errors
+  LiVESList *current_layouts_map; ///< map of all layouts for set
 
-  /// list of pairs of marks in affected_layouts_map, text between them should be deleted when 
+  /// list of pairs of marks in affected_layouts_map, text between them should be deleted when
   /// stored_layout is deleted
-  GList *affected_layout_marks;
+  LiVESList *affected_layout_marks;
 
   /// immediately (to be) affected layout maps
-  GList *xlays;
+  LiVESList *xlays;
 
-  gchar *recovery_file;  ///< the filename of our recover file
+  char *recovery_file;  ///< the filename of our recover file
   boolean leave_recovery;
 
   boolean unordered_blocks; ///< are we recording unordered blocks ?
@@ -977,27 +970,30 @@ typedef struct {
   double rec_avel;
   double rec_aseek;
 
-  gpointer do_not_free; ///< mess with memory so that g_object_unref can be forced not to free() the pixel_data
-  GMemVTable alt_vtable;
-  void (*free_fn)(gpointer);
+  livespointer do_not_free; ///< mess with memory so that lives_object_unref can be forced not to free() the pixel_data
+  LiVESMemVTable alt_vtable;
+  void (* free_fn)(livespointer);
 
   pthread_mutex_t gtk_mutex;  ///< gtk drawing mutex - no longer used
   pthread_mutex_t interp_mutex;  ///< interpolation mutex - parameter interpolation must be single threaded
+  pthread_mutex_t free_fn_mutex; ///< stop threads squelching each others free_fns
 
   pthread_mutex_t abuf_mutex;  ///< used to synch audio buffer request count - shared between audio and video threads
   pthread_mutex_t abuf_frame_mutex;  ///< used to synch audio buffer for generators
   pthread_mutex_t data_mutex[FX_KEYS_MAX];  ///< used to prevent data being connected while it is possibly being updated
   pthread_mutex_t fxd_active_mutex; ///< prevent simultaneous writing to active_dummy by audio and video threads
   pthread_mutex_t event_list_mutex; /// prevent simultaneous writing to event_list by audio and video threads
+  pthread_mutex_t clip_list_mutex; /// prevent adding/removing to cliplist while another thread could be reading it
 
   volatile lives_rfx_t *vrfx_update;
 
-  lives_fx_candidate_t fx_candidates[MAX_FX_CANDIDATE_TYPES]; ///< effects which can have candidates from which a delegate is selected (current examples are: audio_volume, resize)
+  lives_fx_candidate_t
+  fx_candidates[MAX_FX_CANDIDATE_TYPES]; ///< effects which can have candidates from which a delegate is selected (current examples are: audio_volume, resize)
 
-  GList *cached_list;  ///< cache of preferences or file header file (or NULL)
+  LiVESList *cached_list;  ///< cache of preferences or file header file (or NULL)
   FILE *clip_header;
 
-  GList *file_buffers;
+  LiVESList *file_buffers;
 
   float volume; ///< audio volume level (for jack)
 
@@ -1015,12 +1011,12 @@ typedef struct {
 
   boolean no_recurse; ///< flag to prevent recursive function calls
 
-  gchar *string_constants[NUM_LIVES_STRING_CONSTANTS];
-  gchar *any_string;  ///< localised text saying "Any", for encoder and output format
-  gchar *none_string;  ///< localised text saying "None", for playback plugin name, etc.
-  gchar *recommended_string;  ///< localised text saying "recommended", for encoder and output format
-  gchar *disabled_string;  ///< localised text saying "disabled !", for playback plugin name, etc.
-  gchar *cl_string; ///< localised text saying "*The current layout*", for layout warnings
+  char *string_constants[NUM_LIVES_STRING_CONSTANTS];
+  char *any_string;  ///< localised text saying "Any", for encoder and output format
+  char *none_string;  ///< localised text saying "None", for playback plugin name, etc.
+  char *recommended_string;  ///< localised text saying "recommended", for encoder and output format
+  char *disabled_string;  ///< localised text saying "disabled !", for playback plugin name, etc.
+  char *cl_string; ///< localised text saying "*The current layout*", for layout warnings
 
   int opening_frames; ///< count of frames so far opened, updated after preview (currently)
 
@@ -1056,10 +1052,10 @@ typedef struct {
   /// external control inputs
   boolean ext_cntl[MAX_EXT_CNTL];
 
-  #ifdef ALSA_MIDI
+#ifdef ALSA_MIDI
   snd_seq_t *seq_handle;
   int alsa_midi_port;
-  #endif
+#endif
 
   weed_plant_t *rte_textparm; ///< send keyboard input to this paramter (usually NULL)
 
@@ -1075,7 +1071,7 @@ typedef struct {
   boolean soft_debug; ///< for testing
 
   /// encoder text output
-  GIOChannel *iochan;
+  LiVESIOChannel *iochan;
   LiVESTextView *optextview;
 
   boolean has_custom_tools;
@@ -1084,21 +1080,21 @@ typedef struct {
 
   /// decoders
   boolean decoders_loaded;
-  GList *decoder_list;
+  LiVESList *decoder_list;
 
   boolean go_away;
   boolean debug; ///< debug crashes and asserts
 
-  gchar *subt_save_file; ///< name of file to save subtitles to
+  char *subt_save_file; ///< name of file to save subtitles to
 
-  gchar **fonts_array;
+  char **fonts_array;
   int nfonts;
 
-  GtkTargetEntry *target_table; ///< drag and drop target table
+  LiVESTargetEntry *target_table; ///< drag and drop target table
 
-  GList *videodevs;
+  LiVESList *videodevs;
 
-  gchar vpp_defs_file[PATH_MAX];
+  char vpp_defs_file[PATH_MAX];
 
   int log_fd;
 
@@ -1136,9 +1132,9 @@ typedef struct {
   int ce_frame_height;
   int ce_frame_width;
 
-  gchar *read_failed_file;
-  gchar *write_failed_file;
-  gchar *bad_aud_file;
+  char *read_failed_file;
+  char *write_failed_file;
+  char *bad_aud_file;
 
   lives_render_error_t render_error;
 
@@ -1183,14 +1179,19 @@ typedef struct {
 
   lives_audio_buf_t *audio_frame_buffer; ///< used for buffering / feeding audio to video generators
   int afbuffer_clients;
-////////////////////
+
+  pthread_t *libthread;
+  ulong id;
+
+  boolean interactive;
+  ////////////////////
 
 } mainwindow;
 
 extern _palette *palette;
 
 typedef struct {
-  gulong ins_frame_function;
+  ulong ins_frame_function;
 
   LiVESWidget *merge_dialog;
   LiVESWidget *ins_frame_button;
@@ -1203,11 +1204,11 @@ typedef struct {
   boolean ins_frames;
 
   int *list_to_rfx_index;
-  GList *trans_list;
+  LiVESList *trans_list;
 
 } _merge_opts;
 
-extern _merge_opts* merge_opts;
+extern _merge_opts *merge_opts;
 
 /// note, we can only have two of these currently, one for rendered effects, one for real time effects
 /// 0 for rfx, 1 for rte
@@ -1226,13 +1227,13 @@ extern LiVESWidget *fx_dialog[2];
 
 
 #ifdef ENABLE_JACK
-  volatile aserver_message_t jack_message;
-  volatile aserver_message_t jack_message2;
+volatile aserver_message_t jack_message;
+volatile aserver_message_t jack_message2;
 #endif
 
 #ifdef HAVE_PULSE_AUDIO
-  volatile aserver_message_t pulse_message;
-  volatile aserver_message_t pulse_message2;
+volatile aserver_message_t pulse_message;
+volatile aserver_message_t pulse_message2;
 #endif
 
 #endif // HAS_LIVES_MAINWINDOW_H
