@@ -19,7 +19,7 @@
 
 // generic plugins
 
-GList *get_plugin_list (const gchar *plugin_type, boolean allow_nonex, const gchar *plugdir, const gchar *filter_ext);
+LiVESList *get_plugin_list(const char *plugin_type, boolean allow_nonex, const char *plugdir, const char *filter_ext);
 #define PLUGIN_ENCODERS "encoders"
 #define PLUGIN_DECODERS "decoders"
 #define PLUGIN_VID_PLAYBACK "playback/video"
@@ -33,65 +33,66 @@ GList *get_plugin_list (const gchar *plugin_type, boolean allow_nonex, const gch
 #define PLUGIN_WEED_FX_BUILTIN "effects/realtime/weed"
 
 
-GList *plugin_request (const gchar *plugin_type, const gchar *plugin_name, const gchar *request);
-GList *plugin_request_with_blanks (const gchar *plugin_type, const gchar *plugin_name, const gchar *request);
-GList *plugin_request_by_line (const gchar *plugin_type, const gchar *plugin_name, const gchar *request);
-GList *plugin_request_by_space (const gchar *plugin_type, const gchar *plugin_name, const gchar *request);
-GList *plugin_request_common (const gchar *plugin_type, const gchar *plugin_name, const gchar *request, const gchar *delim, boolean allow_blanks);
+LiVESList *plugin_request(const char *plugin_type, const char *plugin_name, const char *request);
+LiVESList *plugin_request_with_blanks(const char *plugin_type, const char *plugin_name, const char *request);
+LiVESList *plugin_request_by_line(const char *plugin_type, const char *plugin_name, const char *request);
+LiVESList *plugin_request_by_space(const char *plugin_type, const char *plugin_name, const char *request);
+LiVESList *plugin_request_common(const char *plugin_type, const char *plugin_name, const char *request, const char *delim,
+                                 boolean allow_blanks);
 
 #ifndef  __WEED_EFFECTS_H__
-typedef weed_plant_t *(*weed_bootstrap_f) (weed_default_getter_f *value, int num_versions, int *plugin_versions);
+typedef weed_plant_t *(*weed_bootstrap_f)(weed_default_getter_f *value, int num_versions, int *plugin_versions);
 #endif
 
 /// video playback plugins
-typedef boolean (*plugin_keyfunc) (boolean down, uint16_t unicode, uint16_t keymod);
+typedef boolean(*plugin_keyfunc)(boolean down, uint16_t unicode, uint16_t keymod);
 
 
 typedef struct {
   // playback
-  gchar name[64];
+  char name[64];
   void *handle;
 
   // mandatory
   const char *(*module_check_init)(void);
-  const char *(*version) (void);
-  const char *(*get_description) (void);
+  const char *(*version)(void);
+  const char *(*get_description)(void);
 
-  int *(*get_palette_list) (void);
-  boolean (*set_palette) (int palette);
-  uint64_t (*get_capabilities) (int palette);
+  int *(*get_palette_list)(void);
+  boolean(*set_palette)(int palette);
+  uint64_t (*get_capabilities)(int palette);
 
-  boolean (*render_frame) (int hsize, int vsize, int64_t timecode, void **pixel_data, void **return_data,
-			    weed_plant_t **play_params);
+  boolean(*render_frame)(int hsize, int vsize, int64_t timecode, void **pixel_data, void **return_data,
+                         weed_plant_t **play_params);
 
   // optional
-  boolean (*init_screen) (int width, int height, boolean fullscreen, uint64_t window_id, int argc, gchar **argv);
-  void (*exit_screen) (uint16_t mouse_x, uint16_t mouse_y);
-  void (*module_unload) (void);
-  const gchar *(*get_fps_list) (int palette);
-  boolean (*set_fps) (double fps);
-  
-  const char *(*get_init_rfx) (void);
+  boolean(*init_screen)(int width, int height, boolean fullscreen, uint64_t window_id, int argc, char **argv);
+  void (*exit_screen)(uint16_t mouse_x, uint16_t mouse_y);
+  void (*module_unload)(void);
+  const char *(*get_fps_list)(int palette);
+  boolean(*set_fps)(double fps);
+
+  const char *(*get_init_rfx)(void);
 
   ///< optional (but should return a weed plantptr array of paramtmpl and chantmpl, NULL terminated)
-  const weed_plant_t **(*get_play_params) (weed_bootstrap_f f); 
-  
+  const weed_plant_t **(*get_play_params)(weed_bootstrap_f f);
+
   // only for display plugins
-  boolean (*send_keycodes) (plugin_keyfunc);
+  boolean(*send_keycodes)(plugin_keyfunc);
 
   // optional for YUV palettes
-  int *(*get_yuv_palette_sampling) (int palette);
-  int *(*get_yuv_palette_clamping) (int palette);
-  int *(*get_yuv_palette_subspace) (int palette);
-  int (*set_yuv_palette_sampling) (int palette);
-  int (*set_yuv_palette_clamping) (int palette);
-  int (*set_yuv_palette_subspace) (int palette);
+  int *(*get_yuv_palette_sampling)(int palette);
+  int *(*get_yuv_palette_clamping)(int palette);
+  int *(*get_yuv_palette_subspace)(int palette);
+  int (*set_yuv_palette_sampling)(int palette);
+  int (*set_yuv_palette_clamping)(int palette);
+  int (*set_yuv_palette_subspace)(int palette);
 
   // audio streaming
   int *(*get_audio_fmts)(void);
 
   uint32_t audio_codec;
-  // must match with the "acodec" GList in interface.c
+  // must match with the "acodec" LiVESList in interface.c
   // and bitmaps in the encder plugins, with this one addition:
 
   uint64_t capabilities;
@@ -112,7 +113,7 @@ typedef struct {
   double fixed_fpsd;
 
   int extra_argc;
-  gchar **extra_argv;
+  char **extra_argv;
 
   const weed_plant_t **play_paramtmpls;
   weed_plant_t **play_params;
@@ -126,12 +127,12 @@ typedef struct {
 #define DEF_VPP_HSIZE 320.
 #define DEF_VPP_VSIZE 240.
 
-_vid_playback_plugin *open_vid_playback_plugin (const gchar *name, boolean in_use);
-void vid_playback_plugin_exit (void);
+_vid_playback_plugin *open_vid_playback_plugin(const char *name, boolean in_use);
+void vid_playback_plugin_exit(void);
 void close_vid_playback_plugin(_vid_playback_plugin *);
 int64_t get_best_audio(_vid_playback_plugin *);
-void save_vpp_defaults(_vid_playback_plugin *, gchar *file);
-void load_vpp_defaults(_vid_playback_plugin *, gchar *file);
+void save_vpp_defaults(_vid_playback_plugin *, char *file);
+void load_vpp_defaults(_vid_playback_plugin *, char *file);
 
 
 const weed_plant_t *pp_get_param(weed_plant_t **pparams, int idx);
@@ -139,12 +140,12 @@ const weed_plant_t *pp_get_chan(weed_plant_t **pparams, int idx);
 
 // encoder plugins
 
-void do_plugin_encoder_error(const gchar *plugin_name_or_null);
+void do_plugin_encoder_error(const char *plugin_name_or_null);
 
-GList *filter_encoders_by_img_ext(GList *encoders, const gchar *img_ext);
+LiVESList *filter_encoders_by_img_ext(LiVESList *encoders, const char *img_ext);
 
 typedef struct {
-  gchar name[51];
+  char name[51];
   uint32_t audio_codec;
   // match with bitmaps in the encoder plugins
   // and also anames array in plugins.c (see below)
@@ -174,11 +175,11 @@ typedef struct {
 #define ENCODER_NON_NATIVE 1<<3
 
   // current output format
-  gchar of_name[51];
-  gchar of_desc[128];
+  char of_name[51];
+  char of_desc[128];
   int of_allowed_acodecs;
-  gchar of_restrict[1024];
-  gchar of_def_ext[16];
+  char of_restrict[1024];
+  char of_def_ext[16];
 }
 _encoder;
 
@@ -191,10 +192,10 @@ extern const char *anames[AUDIO_CODEC_MAX];
 
 // seek_flags is a bitmap
 
-  /// good
+/// good
 #define LIVES_SEEK_FAST (1<<0)
 
-  /// not so good
+/// not so good
 #define LIVES_SEEK_NEEDS_CALCULATION (1<<1)
 #define LIVES_SEEK_QUALITY_LOSS (1<<2)
 
@@ -202,10 +203,10 @@ extern const char *anames[AUDIO_CODEC_MAX];
 // must be exactly the same as in decplugin.h
 
 typedef struct {
-  gchar *URI; ///< the URI of this cdata
+  char *URI; ///< the URI of this cdata
 
   int nclips; ///< number of clips (titles) in container
-  gchar container_name[512]; ///< name of container, e.g. "ogg" or NULL
+  char container_name[512]; ///< name of container, e.g. "ogg" or NULL
 
   char title[256];
   char author[256];
@@ -237,11 +238,11 @@ typedef struct {
 
   /// plugin should init this to palettes[0] if URI changes
   int current_palette;  ///< current palette [rw host]; must be contained in palettes
-  
+
   int YUV_sampling;
   int YUV_clamping;
   int YUV_subspace;
-  gchar video_name[512]; ///< name of video codec, e.g. "theora" or NULL
+  char video_name[512]; ///< name of video codec, e.g. "theora" or NULL
 
   /* audio data */
   int arate;
@@ -249,7 +250,7 @@ typedef struct {
   int asamps;
   boolean asigned;
   boolean ainterleaf;
-  gchar audio_name[512]; ///< name of audio codec, e.g. "vorbis" or NULL
+  char audio_name[512]; ///< name of audio codec, e.g. "vorbis" or NULL
 
   int seek_flag;
 
@@ -272,11 +273,11 @@ typedef struct {
 
 typedef struct {
   // playback
-  gchar *name; ///< plugin name
+  char *name; ///< plugin name
   void *handle; ///< may be shared between several instances
 
   // mandatory
-  const char *(*version) (void);
+  const char *(*version)(void);
 
   /// call first time with NULL cdata
   /// subsequent calls should re-use cdata
@@ -290,17 +291,17 @@ typedef struct {
   lives_clip_data_t *(*get_clip_data)(char *URI, const lives_clip_data_t *cdata);
 
   /// frame starts at 0 in these functions; height is height of primary plane
-  boolean (*get_frame)(const lives_clip_data_t *, int64_t frame, int *rowstrides, int height, void **pixel_data);
+  boolean(*get_frame)(const lives_clip_data_t *, int64_t frame, int *rowstrides, int height, void **pixel_data);
 
   /// call this for each cdata before unloading the module
   void (*clip_data_free)(lives_clip_data_t *);
 
   // optional
   const char *(*module_check_init)(void);
-  boolean (*set_palette)(lives_clip_data_t *);
-  int64_t (*rip_audio) (const lives_clip_data_t *, const char *fname, int64_t stframe, int64_t nframes, 
-			unsigned char **abuff);
-  void (*rip_audio_cleanup) (const lives_clip_data_t *cdata);
+  boolean(*set_palette)(lives_clip_data_t *);
+  int64_t (*rip_audio)(const lives_clip_data_t *, const char *fname, int64_t stframe, int64_t nframes,
+                       unsigned char **abuff);
+  void (*rip_audio_cleanup)(const lives_clip_data_t *cdata);
   void (*module_unload)(void);
 
 } lives_decoder_sys_t;
@@ -317,13 +318,13 @@ typedef struct {
 
 
 
-const lives_clip_data_t *get_decoder_cdata(int fileno, GList *disabled, const lives_clip_data_t *fake_cdata);
-void close_decoder_plugin (lives_decoder_t *);
-lives_decoder_sys_t *open_decoder_plugin(const gchar *plname);
-void get_mime_type(gchar *text, int maxlen, const lives_clip_data_t *);
+const lives_clip_data_t *get_decoder_cdata(int fileno, LiVESList *disabled, const lives_clip_data_t *fake_cdata);
+void close_decoder_plugin(lives_decoder_t *);
+lives_decoder_sys_t *open_decoder_plugin(const char *plname);
+void get_mime_type(char *text, int maxlen, const lives_clip_data_t *);
 void unload_decoder_plugins(void);
 
-boolean decplugin_supports_palette (const lives_decoder_t *dplug, int palette);
+boolean decplugin_supports_palette(const lives_decoder_t *dplug, int palette);
 
 lives_decoder_t *clone_decoder(int fileno);
 
@@ -367,7 +368,7 @@ typedef enum {
   LIVES_PARAM_COLRGBA32,
 
   LIVES_PARAM_UNDISPLAYABLE=65536
-  
+
 } lives_param_type_t;
 
 
@@ -399,10 +400,10 @@ typedef enum {
 
 typedef struct {
   // weed style part
-  gchar *name;
-  gchar *desc;
+  char *name;
+  char *desc;
 
-  gchar *label;
+  char *label;
   int flags;
   boolean use_mnemonic;
   fn_ptr interp_func;
@@ -431,7 +432,7 @@ typedef struct {
   double max; ///< for string this is max characters
 
   void *def; ///< default values
-  GList *list; ///< for string list (choices)
+  LiVESList *list; ///< for string list (choices)
 
   /// multivalue type - single value, multi value, or per channel
   short multi;
@@ -478,9 +479,9 @@ typedef enum {
 
 
 typedef struct {
-  gchar *name;  ///< the name of the executable (so we can run it !)
-  gchar *menu_text; ///< for Weed, this is the filter_class "name"
-  gchar *action_desc; ///< for Weed "Applying $s"
+  char *name;  ///< the name of the executable (so we can run it !)
+  char *menu_text; ///< for Weed, this is the filter_class "name"
+  char *action_desc; ///< for Weed "Applying $s"
   int min_frames; ///< for Weed, 1
   int num_in_channels;
   lives_rfx_status_t status;
@@ -503,37 +504,37 @@ typedef struct {
   lives_rfx_source_t source_type;
   void *source;  ///< points to the source (e.g. a weed_plant_t)
   void *extra;  ///< for future use
-  gchar delim[2];
+  char delim[2];
   boolean is_template;
 
 } lives_rfx_t;
 
 
-boolean check_rfx_for_lives (lives_rfx_t *);
+boolean check_rfx_for_lives(lives_rfx_t *);
 
 void do_rfx_cleanup(lives_rfx_t *);
 
-void render_fx_get_params (lives_rfx_t *, const gchar *plugin_name, short status);
+void render_fx_get_params(lives_rfx_t *, const char *plugin_name, short status);
 
-void sort_rfx_array (lives_rfx_t *in_array, int num_elements);
+void sort_rfx_array(lives_rfx_t *in_array, int num_elements);
 
-int find_rfx_plugin_by_name (const gchar *name, short status);
+int find_rfx_plugin_by_name(const char *name, short status);
 
-void rfx_copy (lives_rfx_t *src, lives_rfx_t *dest, boolean full);
+void rfx_copy(lives_rfx_t *src, lives_rfx_t *dest, boolean full);
 
 void rfx_params_free(lives_rfx_t *rfx);
 
 void rfx_free(lives_rfx_t *rfx);
 
-void rfx_free_all (void);
+void rfx_free_all(void);
 
-void param_copy (lives_param_t *src, lives_param_t *dest, boolean full);
+void param_copy(lives_param_t *src, lives_param_t *dest, boolean full);
 
 
 typedef struct {
-  GList *list; ///< list of filter_idx from which user can delegate
+  LiVESList *list; ///< list of filter_idx from which user can delegate
   int delegate; ///< offset in list of current delegate
-  gulong func; ///< menuitem activation function for current delegate
+  ulong func; ///< menuitem activation function for current delegate
   lives_rfx_t *rfx; ///< pointer to rfx for current delegate (or NULL)
 } lives_fx_candidate_t;
 
@@ -554,23 +555,23 @@ double get_double_param(void *value);
 void get_colRGB24_param(void *value, lives_colRGB24_t *rgb);
 void get_colRGBA32_param(void *value, lives_colRGBA32_t *rgba);
 
-void set_bool_param(void *value, boolean );
-void set_int_param(void *value, int );
-void set_double_param(void *value, double );
+void set_bool_param(void *value, boolean);
+void set_int_param(void *value, int);
+void set_double_param(void *value, double);
 void set_colRGB24_param(void *value, short red, short green, short blue);
 void set_colRGBA32_param(void *value, short red, short green, short blue, short alpha);
 
 /// return an array of parameter values
-void **store_rfx_params (lives_rfx_t *);
-void set_rfx_params_from_store (lives_rfx_t *rfx, void **store);
-void rfx_params_store_free (lives_rfx_t *, void **store);
+void **store_rfx_params(lives_rfx_t *);
+void set_rfx_params_from_store(lives_rfx_t *rfx, void **store);
+void rfx_params_store_free(lives_rfx_t *, void **store);
 
-GList *array_to_string_list (gchar **array, int offset, int len);
+LiVESList *array_to_string_list(char **array, int offset, int len);
 
-lives_rfx_t *weed_to_rfx (weed_plant_t *plant, boolean show_reinits);
+lives_rfx_t *weed_to_rfx(weed_plant_t *plant, boolean show_reinits);
 lives_param_t *weed_params_to_rfx(int npar, weed_plant_t *instance, boolean show_reinits);
 
-gchar *plugin_run_param_window(const gchar *get_com, LiVESVBox *vbox, lives_rfx_t **ret_rfx);
+char *plugin_run_param_window(const char *get_com, LiVESVBox *vbox, lives_rfx_t **ret_rfx);
 
 //////////////////////////////////////////////////////////////////////////////////////////
 /// video playback plugin window - fixed part
@@ -584,8 +585,8 @@ typedef struct {
   lives_rfx_t *rfx;
 } _vppaw;
 
-_vppaw *on_vpp_advanced_clicked (LiVESButton *, gpointer);
-void on_decplug_advanced_clicked (LiVESButton *button, gpointer user_data);
+_vppaw *on_vpp_advanced_clicked(LiVESButton *, livespointer);
+void on_decplug_advanced_clicked(LiVESButton *button, livespointer user_data);
 
 
 /// for realtime effects, see effects-weed.h
