@@ -12,10 +12,10 @@
 #define PREFS_PANED_POS ((int)(200.*widget_opts.scale))
 
 typedef struct {
-  gchar bgcolour[256];
+  char bgcolour[256];
   boolean stop_screensaver;
   boolean open_maximised;
-  gchar theme[64];  ///< the theme name
+  char theme[64];  ///< the theme name
 
   short pb_quality;
 #define PB_QUALITY_LOW 1
@@ -31,29 +31,28 @@ typedef struct {
 #define AUD_PLAYER_PULSE 4
 #define AUD_PLAYER_MPLAYER2 5
 
-  gchar aplayer[512]; // name, eg. "jack","pulse","sox","mplayer","mplayer2"
+  char aplayer[512]; // name, eg. "jack","pulse","sox","mplayer","mplayer2"
 
   /// frame quantisation type
   short q_type;
 #define Q_FILL 1
 #define Q_SMOOTH 1
 
-  gchar tmpdir[PATH_MAX];  ///< kept in locale encoding
+  char tmpdir[PATH_MAX];  ///< kept in locale encoding
 
-  // TODO - also use cur_vid_load_dir, etc.
   // utf8 encoding
-  gchar def_vid_load_dir[PATH_MAX];
-  gchar def_vid_save_dir[PATH_MAX];
-  gchar def_audio_dir[PATH_MAX];
-  gchar def_image_dir[PATH_MAX];
-  gchar def_proj_dir[PATH_MAX];
+  char def_vid_load_dir[PATH_MAX];
+  char def_vid_save_dir[PATH_MAX];
+  char def_audio_dir[PATH_MAX];
+  char def_image_dir[PATH_MAX];
+  char def_proj_dir[PATH_MAX];
 
   // locale encoding
-  gchar prefix_dir[PATH_MAX];
-  gchar lib_dir[PATH_MAX];
+  char prefix_dir[PATH_MAX];
+  char lib_dir[PATH_MAX];
 
 
-  gchar image_ext[16];
+  char image_ext[16];
 
   uint32_t warning_mask;
   // if these bits are set, we do not show the warning
@@ -84,7 +83,7 @@ typedef struct {
 #define WARN_MASK_MT_ACHANS (1<<16)
 
 #define WARN_MASK_LAYOUT_DELETE_AUDIO (1<<17)
-  
+
   /* next two are off by default (on a fresh install) */
 #define WARN_MASK_LAYOUT_SHIFT_AUDIO (1<<18)
 #define WARN_MASK_LAYOUT_ALTER_AUDIO (1<<19)
@@ -103,10 +102,10 @@ typedef struct {
 
 #define WARN_MASK_LAYOUT_WIPE (1<<26)
 
-  gchar effect_command[256];
-  gchar video_open_command[256];
-  gchar audio_play_command[256];
-  gchar cdplay_device[PATH_MAX];  ///< locale encoding
+  char effect_command[256];
+  char video_open_command[256];
+  char audio_play_command[256];
+  char cdplay_device[PATH_MAX];  ///< locale encoding
   double default_fps;
   int bar_height;
   boolean pause_effect_during_preview;
@@ -139,7 +138,7 @@ typedef struct {
 #define REC_CLIPS (1<<3)
 #define REC_AUDIO (1<<4)
 #define REC_AFTER_PB (1<<5)
-  
+
 
   int audio_src;
 #define AUDIO_SRC_INT 0
@@ -153,7 +152,7 @@ typedef struct {
   boolean omc_events; ///< send other events
 
   short startup_phase; ///< -1 = fresh install, 1 = tmpdir set, 2, pre-audio start, 3, pre-tests, 100 = all tests passed
-  gchar *wm; ///<window manager name
+  char *wm; ///<window manager name
   int ocp; ///< open_compression_percent : get/set in prefs
 
   boolean antialias;
@@ -173,14 +172,14 @@ typedef struct {
 #define JACK_OPTS_TIMEBASE_MASTER (1<<7)   ///< timebase master (not implemented yet)
 #define JACK_OPTS_NO_READ_AUTOCON (1<<8)   ///< do not auto connect read clients when playing ext audio
 
-  gchar jack_tserver[256];
-  gchar jack_aserver[256];
+  char jack_tserver[256];
+  char jack_aserver[256];
 
-  gchar *fxdefsfile;
-  gchar *fxsizesfile;
-  gchar *vppdefaultsfile;
+  char *fxdefsfile;
+  char *fxsizesfile;
+  char *vppdefaultsfile;
 
-  GList *acodec_list;
+  LiVESList *acodec_list;
   int acodec_list_to_format[AUDIO_CODEC_NONE];
 
   uint32_t audio_opts;
@@ -217,8 +216,8 @@ typedef struct {
   boolean ar_clipset;
   boolean ar_layout;
 
-  gchar ar_clipset_name[128]; ///< utf8 (not converted (to locale?))
-  gchar ar_layout_name[PATH_MAX];  ///< utf8 (not converted) 
+  char ar_clipset_name[128]; ///< locale
+  char ar_layout_name[PATH_MAX];  ///< locale
 
   boolean rec_desktop_audio;
 
@@ -228,8 +227,6 @@ typedef struct {
 
   boolean osc_start;
 
-  boolean collate_images;
-
   int virt_height; ///< n screens vert.
 
   boolean concat_images;
@@ -254,9 +251,9 @@ typedef struct {
 #define OMC_DEV_FORCE_RAW_MIDI 1<<2
   uint32_t omc_dev_opts;
 
-  gchar omc_js_fname[PATH_MAX];  ///< utf8
-  gchar omc_midi_fname[PATH_MAX]; ///< utf8
-  
+  char omc_js_fname[PATH_MAX];  ///< utf8
+  char omc_midi_fname[PATH_MAX]; ///< utf8
+
   boolean mouse_scroll_clips;
 
   int num_rtaudiobufs;
@@ -284,7 +281,7 @@ typedef struct {
 
   // autotransitioning in mt
   int atrans_fx;
-  gchar def_autotrans[256];
+  char def_autotrans[256];
 
   int nfx_threads;
 
@@ -325,10 +322,10 @@ typedef struct {
   uint32_t clear_disk_opts;
 
 #ifdef HAVE_YUV4MPEG
-  gchar yuvin[PATH_MAX];
+  char yuvin[PATH_MAX];
 #endif
 
-  GList *disabled_decoders;
+  LiVESList *disabled_decoders;
 
   char backend_sync[PATH_MAX];
   char backend[PATH_MAX];
@@ -350,27 +347,27 @@ typedef struct {
 } _prefs;
 
 enum {
-    LIST_ENTRY_GUI,
-    LIST_ENTRY_DECODING,
-    LIST_ENTRY_PLAYBACK,
-    LIST_ENTRY_RECORDING,
-    LIST_ENTRY_ENCODING,
-    LIST_ENTRY_EFFECTS,
-    LIST_ENTRY_DIRECTORIES,
-    LIST_ENTRY_WARNINGS,
-    LIST_ENTRY_MISC,
-    LIST_ENTRY_THEMES,
-    LIST_ENTRY_NET,
-    LIST_ENTRY_JACK,
-    LIST_ENTRY_MIDI,
-    LIST_ENTRY_MULTITRACK
+  LIST_ENTRY_GUI,
+  LIST_ENTRY_DECODING,
+  LIST_ENTRY_PLAYBACK,
+  LIST_ENTRY_RECORDING,
+  LIST_ENTRY_ENCODING,
+  LIST_ENTRY_EFFECTS,
+  LIST_ENTRY_DIRECTORIES,
+  LIST_ENTRY_WARNINGS,
+  LIST_ENTRY_MISC,
+  LIST_ENTRY_THEMES,
+  LIST_ENTRY_NET,
+  LIST_ENTRY_JACK,
+  LIST_ENTRY_MIDI,
+  LIST_ENTRY_MULTITRACK
 };
 
 enum {
-    LIST_ICON = 0,
-    LIST_ITEM,
-    LIST_NUM,
-    N_COLUMNS
+  LIST_ICON = 0,
+  LIST_ITEM,
+  LIST_NUM,
+  N_COLUMNS
 };
 
 
@@ -381,10 +378,10 @@ enum {
 
 /// prefs window
 typedef struct {
-  gulong encoder_ofmt_fn;
-  gulong encoder_name_fn;
+  ulong encoder_ofmt_fn;
+  ulong encoder_name_fn;
   LiVESWidget *prefs_dialog;
-  
+
   LiVESWidget *prefs_list;
   LiVESWidget *prefs_table;
   LiVESWidget *vbox_right_gui;
@@ -526,10 +523,10 @@ typedef struct {
   LiVESWidget *checkbutton_concat_images;
   LiVESWidget *forcesmon;
   LiVESWidget *forcesmon_hbox;
-  GList *pbq_list;
-  gchar *audp_name;
-  gchar *orig_audp_name;
-  gulong audp_entry_func;
+  LiVESList *pbq_list;
+  char *audp_name;
+  char *orig_audp_name;
+  ulong audp_entry_func;
   LiVESWidget *checkbutton_omc_js;
   LiVESWidget *checkbutton_omc_midi;
   LiVESWidget *omc_js_entry;
@@ -564,9 +561,9 @@ typedef struct {
 } _ign_opts;
 
 typedef struct {
-  gchar tmpdir[PATH_MAX];
-  gchar theme[64];
-  gchar vpp_name[64]; ///< new video playback plugin
+  char tmpdir[PATH_MAX];
+  char theme[64];
+  char vpp_name[64]; ///< new video playback plugin
   int vpp_fixed_fps_numer;
   int vpp_fixed_fps_denom;
   double vpp_fixed_fpsd;
@@ -575,7 +572,7 @@ typedef struct {
   int vpp_fwidth;
   int vpp_fheight;
   int vpp_argc;
-  gchar **vpp_argv;
+  char **vpp_argv;
 
   _encoder encoder;
   boolean show_recent;
@@ -587,8 +584,8 @@ typedef struct {
   int nfx_threads;
 
 
-  GList *disabled_decoders;
-  GList *disabled_decoders_new;
+  LiVESList *disabled_decoders;
+  LiVESList *disabled_decoders_new;
 
 } _future_prefs;
 
@@ -596,31 +593,44 @@ _prefs *prefs;
 _future_prefs *future_prefs;
 _prefsw *prefsw;
 
-void set_acodec_list_from_allowed (_prefsw *, render_details *);
-void  rdet_acodec_changed (LiVESCombo *acodec_combo, gpointer user_data);
+void set_acodec_list_from_allowed(_prefsw *, render_details *);
+void  rdet_acodec_changed(LiVESCombo *acodec_combo, livespointer user_data);
 
-_prefsw* create_prefs_dialog (void);
+_prefsw *create_prefs_dialog(void);
 
-boolean on_prefs_delete_event (LiVESWidget *, LiVESXEvent *, gpointer prefsw);
+boolean on_prefs_delete_event(LiVESWidget *, LiVESXEvent *, livespointer prefsw);
 
-void on_preferences_activate (LiVESMenuItem *, gpointer);
+void on_preferences_activate(LiVESMenuItem *, livespointer);
 
-void on_prefs_close_clicked (LiVESButton *, gpointer);
+void on_prefs_close_clicked(LiVESButton *, livespointer);
 
-void on_prefs_revert_clicked (LiVESButton *, gpointer);
+void on_prefs_revert_clicked(LiVESButton *, livespointer);
 
 void set_vpp(boolean set_in_prefs);
 
-void on_prefDomainChanged(LiVESTreeSelection *, gpointer);
+void on_prefDomainChanged(LiVESTreeSelection *, livespointer);
 
-void populate_combo_box(LiVESCombo *, GList *data);
+void populate_combo_box(LiVESCombo *, LiVESList *data);
 
-void set_combo_box_active_string(LiVESCombo *, gchar *active_str);
+void set_combo_box_active_string(LiVESCombo *, char *active_str);
 
 void prefsw_set_astream_settings(_vid_playback_plugin *);
 void prefsw_set_rec_after_settings(_vid_playback_plugin *);
 
-void apply_button_set_enabled(LiVESWidget *widget, gpointer func_data);
+void apply_button_set_enabled(LiVESWidget *widget, livespointer func_data);
+
+
+// factories
+enum {
+  PREF_REC_EXT_AUDIO,
+  PREF_AUDIO_OPTS,
+  PREF_SEPWIN_STICKY,
+  PREF_MT_EXIT_RENDER
+};
+
+void pref_factory_bool(int prefidx, boolean newval);
+void pref_factory_int(int prefidx, int newval);
+void pref_factory_bitmapped(int prefidx, int bitfield, boolean newval);
 
 
 // permissions
